<?php

namespace App\Traits;

use App\Constants\Status;
use App\Models\Playlist;
use App\Models\User;
use App\Models\Video;

trait ChannelManager {
    protected $guest = false;

    public function channel($slug = null) {
        $user = auth()->user();
        if ($slug) {
            $user = User::where('profile_complete', Status::YES)
                ->active()->where('slug', $slug)
                ->firstOrFail();
        }
        $pageTitle = 'Channel Profile';

        $videos = Video::where('user_id', $user->id)
            ->where(function ($query) use ($user) {
                if ($user->id != auth()->id()) {
                    $query->public();
                }
            })
            ->with('subtitles', 'videoFiles')
            ->regular()
            ->latest()
            ->published()
            ->paginate(getPaginate());

        $subscriberCount = $user->subscribers()->count();
        $videosCount     = $user->videos()->published()->count();
        $bladeName       = 'profile';

        return view('Template::user.channel.channel_preview', compact('user', 'pageTitle', 'videos', 'bladeName', 'subscriberCount', 'videosCount'));
    }

    public function shorts($slug = null) {
        if ($slug) {

            $user = User::where('profile_complete', Status::YES)
                ->active()->where('slug', $slug)
                ->firstOrFail();
        }

        if ($user->profile_complete == Status::NO) {
            return to_route('user.channel.create');
        }

        $pageTitle = 'All Shorts';
        $videos    = Video::where('user_id', $user->id)
            ->where(function ($query) use ($user) {
                if ($user->id != auth()->id()) {
                    $query->public();
                }
            })
            ->with('subtitles')
            ->shorts()
            ->latest()
            ->published()
            ->paginate(getPaginate());

        $bladeName = 'shorts';

        return view('Template::user.channel.channel_preview', compact('user', 'pageTitle', 'videos', 'bladeName'));
    }

    public function playlist($slug = null) {
        if ($slug) {
            $user = User::where('profile_complete', Status::YES)
                ->active()->where('slug', $slug)
                ->firstOrFail();
        }

        if ($user->profile_complete == Status::NO) {
            return to_route('user.channel.create');
        }

        $pageTitle = 'Playlist';
        $playlists = Playlist::where('user_id', $user->id)
            ->where(function ($query) use ($user) {
                if ($user->id != auth()->id()) {
                    $query->public();
                }
            })->orderBy('id', 'desc')
            ->paginate(getPaginate());

        $bladeName = 'playlist';

        return view('Template::user.channel.channel_preview', compact('pageTitle', 'playlists', 'bladeName', 'user'));
    }

    public function about($slug = null) {
        if ($slug) {
            $user = User::where('profile_complete', Status::YES)->active()->where('slug', $slug)->firstOrFail();
        }
        if ($user->profile_complete == Status::NO) {
            return to_route('user.channel.create');
        }
        $bladeName = 'about';
        $pageTitle = 'About Channel';
        return view('Template::user.channel.channel_preview', compact('pageTitle', 'bladeName', 'user'));
    }

    public function playlistVideos($playlistSlug, $slug = null) {
        if ($slug) {
            $user = User::where('profile_complete', Status::YES)
                ->active()->where('slug', $slug)
                ->firstOrFail();
        }

        $playlist = Playlist::where('user_id', $user->id)->where('slug', $playlistSlug)
            ->where(function ($query) use ($user) {
                if ($user->id != auth()->id()) {
                    $query->public();
                }
            })
            ->firstOrFail();

        $videos = $playlist
            ->videos()
            ->where(function ($q) use ($user) {
                if ($user->id != auth()->id()) {
                    $q->public();
                }
            })
            ->published()
            ->paginate(getPaginate());

        $videoLists = Video::published()
            ->where('user_id', $user->id)
            ->whereDoesntHave('playlists', function ($q) use ($playlist) {
                $q->where('playlist_id', $playlist->id);
            })
            ->paginate(getPaginate());

        $bladeName = 'videos';
        $pageTitle = 'Playlists Videos';

        return view('Template::user.channel.channel_preview', compact('pageTitle', 'bladeName', 'playlist', 'user', 'videos', 'videoLists'));
    }
}
